// -*- mode: C++; c-file-style: "Stroustrup" -*-
//
// This file is part of krot,
// a program for the simulation, assignment and fit of HRLIF spectra.
//
// Copyright (C) 1998 Jochen Kpper
//
// This program is free software; you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
// more details.
//
// You should have received a copy of the GNU General Public License along with
// this program; see the file License. if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 , USA
//
// If you use this program for your scientific work, please cite it according to
// the file CITATION that comes with the package.
//
// $Id: mainwindow_inline.h,v 1.6 1998/09/25 18:06:23 jochen Exp $



#ifndef KROT_MAINWINDOW_INLINE_H
#define KROT_MAINWINDOW_INLINE_H


#include "deleteSet.h"
#include "foldSet.h"
#include "krotData.h"
#include "mainwindow.h"
#include "workarea.h"

#include <kapp.h>
#include <kmsgbox.h>



inline void MainWindow::clearAll()
{
    if( ! krotData->empty() ) {
	KMsgBox::yesNo( this, i18n( "Kill datasets" ),
			i18n( "Are you sure you want to kill all datasets ?" ),
			KMsgBox::QUESTION | KMsgBox::DB_SECOND,
			i18n( "Yes" ), i18n( "No" ) );
	krotData->eraseAll();
	setMessage( i18n( "All datasets killed" ) );
    } else {
	setMessage( i18n( "No dataset loaded" ) );
    }
    return;
}



inline void MainWindow::deleteSet()
{
    if( ! krotData->empty() ) {
	DialogDeleteSet dialog( krotData );
	connect( &dialog, SIGNAL( deleted() ),
		 view, SLOT( update() ) );
	connect( &dialog, SIGNAL( message( const char * ) ),
		 this, SLOT( setMessage( const char * ) ) );
    } else
	KMsgBox::message( this, i18n( "No DataSet" ),
			  i18n( "There is no DataSet loaded right now.\nCannot delete!" ),
			  KMsgBox::EXCLAMATION, i18n( "OK" ) );
    return;
}



inline void MainWindow::setFreq( const int64_t freq )
{
    char msg[16];
#if SIZEOF_LONG < 8
    sprintf( msg, "%10lld MHz", freq );
#else
    sprintf( msg, "%10ld MHz", freq );
#endif
    statusBar()->changeItem( msg, ID_FREQUENCY );
    return;
}


inline void MainWindow::foldSet()
{
    if( ! krotData->empty( KRotData::SIMULATIONS ) ) {
	if( ! dialogFoldSet ) {
	    dialogFoldSet = new DialogFoldSet( krotData );
	    connect( dialogFoldSet, SIGNAL( changed() ),
		     view, SLOT( update() ) );
	}
	dialogFoldSet->exec();
    } else
	KMsgBox::message( this, i18n( "No Simulation" ),
			  i18n( "There is no Simulation loaded right now." ),
			  KMsgBox::EXCLAMATION, i18n( "OK" ) );
    return;
}



inline void MainWindow::save()
{
    KMsgBox::message( this, i18n( "Save" ),
		      i18n( "MainWindow::save not implemented yet!" ),
		      KMsgBox::EXCLAMATION, i18n( "OK" ) );
    return;
}



#endif
